---
title: <span class="badge object-type-enum"></span> GrafanaTemplateVariableQueryType
---
# <span class="badge object-type-enum"></span> GrafanaTemplateVariableQueryType

## Definition

```python
class GrafanaTemplateVariableQueryType(enum.StrEnum):
    APP_INSIGHTS_METRIC_NAME_QUERY = "AppInsightsMetricNameQuery"
    APP_INSIGHTS_GROUP_BY_QUERY = "AppInsightsGroupByQuery"
    SUBSCRIPTIONS_QUERY = "SubscriptionsQuery"
    RESOURCE_GROUPS_QUERY = "ResourceGroupsQuery"
    RESOURCE_NAMES_QUERY = "ResourceNamesQuery"
    METRIC_NAMESPACE_QUERY = "MetricNamespaceQuery"
    METRIC_NAMES_QUERY = "MetricNamesQuery"
    WORKSPACES_QUERY = "WorkspacesQuery"
    UNKNOWN_QUERY = "UnknownQuery"
```
